@@ -1,6 +1,6 @@
+from .settings import *
 
-from settings import *
 
 NOSE_PLUGINS = [
     'testapp.plugins.SanityCheckPlugin'
-]
\ No newline at end of file
+]
